# BlackJAX
![CI](https://github.com/blackjax-devs/blackjax/workflows/Run%20tests/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/blackjax-devs/blackjax/branch/master/graph/badge.svg)](https://codecov.io/gh/blackjax-devs/blackjax)

# How to contribute?

1. `pip install -r requirements-dev.txt`
2. Run `make lint` and `make test` before pushing on the repo; CI should pass if
   these pass locally.
